# PacoteLegal

**PacoteLegal** é um app do terminal para utilizar um crud de usuarios

## Dependências
**Python 3.6^=**

Pacote **json**
Pacote **pathlib**
Pacote **typing**

## Começando o uso
Você vai precisar instalar o pacote **pacoteLegal**, para isso basta executar:
```
pip install pacoteLegal
```

## Função

- `menu()`- Executa o menu de seleção de ações